#!/usr/bin/env python
# -*- coding: utf-8 -*-
'''
Created on 2017-12-20

@author: liuqun
'''


COMMON_PARAM_KEYS = set()

P_APP_ID = "app_id"
COMMON_PARAM_KEYS.add(P_APP_ID)

P_METHOD = "method"
COMMON_PARAM_KEYS.add(P_METHOD)

P_FORMAT = "format"
COMMON_PARAM_KEYS.add(P_FORMAT)

P_CHARSET = "charset"
COMMON_PARAM_KEYS.add(P_CHARSET)

P_SIGN_TYPE = "sign_type"
COMMON_PARAM_KEYS.add(P_SIGN_TYPE)

P_SIGN = "sign"
COMMON_PARAM_KEYS.add(P_SIGN)

P_ENCRYPT_TYPE = "encrypt_type"
COMMON_PARAM_KEYS.add(P_ENCRYPT_TYPE)

P_TIMESTAMP = "timestamp"
COMMON_PARAM_KEYS.add(P_TIMESTAMP)

P_VERSION = "version"
COMMON_PARAM_KEYS.add(P_VERSION)

P_NOTIFY_URL = "notify_url"
COMMON_PARAM_KEYS.add(P_NOTIFY_URL)

P_RETURN_URL = "return_url"
COMMON_PARAM_KEYS.add(P_RETURN_URL)

P_AUTH_TOKEN = "auth_token"
COMMON_PARAM_KEYS.add(P_AUTH_TOKEN)

P_APP_AUTH_TOKEN = "app_auth_token"
COMMON_PARAM_KEYS.add(P_APP_AUTH_TOKEN)

P_BIZ_CONTENT = "biz_content"

